/*
 * Copyright 2013 2013 Canonical Ltd.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of version 3 of the GNU Lesser General Public
 * License as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "./download_struct.h"

DownloadStruct::DownloadStruct()
    : m_url(""),
      m_hash(""),
      m_algorithm(""),
      m_metadata(),
      m_headers() {
}

DownloadStruct::DownloadStruct(const QString& url,
                               const QVariantMap& metadata,
                               const QMap<QString, QString>& headers)
    : m_url(url),
      m_hash(""),
      m_algorithm(""),
      m_metadata(metadata),
      m_headers(headers) {
}

DownloadStruct::DownloadStruct(const QString& url,
                               const QString& hash,
                               const QString& algorithm,
                               const QVariantMap& metadata,
                               const QMap<QString, QString>& headers)
    : m_url(url),
      m_hash(hash),
      m_algorithm(algorithm),
      m_metadata(metadata),
      m_headers(headers) {
}

DownloadStruct::DownloadStruct(const DownloadStruct& other)
    : m_url(other.m_url),
      m_hash(other.m_hash),
      m_algorithm(other.m_algorithm),
      m_metadata(other.m_metadata),
      m_headers(other.m_headers) {
}

DownloadStruct& DownloadStruct::operator=(const DownloadStruct& other) {
    m_url = other.m_url;
    m_hash = other.m_hash;
    m_algorithm = other.m_algorithm;
    m_metadata = other.m_metadata;
    m_headers = other.m_headers;

    return *this;
}

DownloadStruct::~DownloadStruct() {
}

QDBusArgument &operator<<(QDBusArgument &argument,
                          const DownloadStruct& download) {
    argument.beginStructure();
    argument << download.m_url;
    argument << download.m_hash;
    argument << download.m_algorithm;
    argument << download.m_metadata;
    argument << download.m_headers;
    argument.endStructure();

    return argument;
}

const QDBusArgument &operator>>(const QDBusArgument &argument,
                                DownloadStruct& download) {
    argument.beginStructure();
    argument >> download.m_url;
    argument >> download.m_hash;
    argument >> download.m_algorithm;
    argument >> download.m_metadata;
    argument >> download.m_headers;
    argument.endStructure();

    return argument;
}

QString DownloadStruct::getUrl() {
    return m_url;
}

QString DownloadStruct::getHash() {
    return m_hash;
}

QString DownloadStruct::getAlgorithm() {
    return m_algorithm;
}

QVariantMap DownloadStruct::getMetadata() {
    return m_metadata;
}

QMap<QString, QString> DownloadStruct::getHeaders() {
    return m_headers;
}
