/*
 * Copyright (C) 2013 - Canonical Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License, as
 * published by the  Free Software Foundation; either version 2.1 or 3.0
 * of the License.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranties of
 * MERCHANTABILITY, SATISFACTORY QUALITY or FITNESS FOR A PARTICULAR
 * PURPOSE.  See the applicable version of the GNU Lesser General Public
 * License for more details.
 *
 * You should have received a copy of both the GNU Lesser General Public
 * License along with this program. If not, see <http://www.gnu.org/licenses/>
 *
 * Authored by: Diego Sarmentero <diego.sarmentero@canonical.com>
 */


#include "download_tracker.h"
#include <QDebug>

namespace UpdatePlugin {

DownloadTracker::DownloadTracker(QObject *parent) :
    QObject(parent)
{
}

DownloadTracker::~DownloadTracker()
{
    delete m_adaptor;
}

bool DownloadTracker::isServiceReady()
{
    bool ready = false;
    if (m_adaptor != NULL) {
        ready = m_adaptor->isValid();
    }

    return ready;
}

void DownloadTracker::setDbusPath(const QString& path)
{
    if (path != "") {
        m_dbusPath = path;
        startService();
    }
}

void DownloadTracker::setService(const QString& service)
{
    if (service != "") {
        m_service = service;
        startService();
    }
}

void DownloadTracker::startService()
{
    if (!m_service.isEmpty() && !m_dbusPath.isEmpty()) {
        qDebug() << "service:" << m_service << m_dbusPath;
        m_adaptor = new DownloadTrackerAdaptor(m_service, m_dbusPath,
                                             QDBusConnection::sessionBus(), 0);

        connect(m_adaptor, SIGNAL(canceled(bool)), this, SIGNAL(canceled(bool)));
        connect(m_adaptor, SIGNAL(error(const QString &)), this,
                SIGNAL(error(const QString &)));
        connect(m_adaptor, SIGNAL(finished(const QString &)), this,
                SIGNAL(finished(const QString &)));
        connect(m_adaptor, SIGNAL(paused(bool)), this, SIGNAL(paused(bool)));
        connect(m_adaptor, SIGNAL(progress(qulonglong, qulonglong)), this,
                SIGNAL(progress(qulonglong, qulonglong)));
        connect(m_adaptor, SIGNAL(resumed(bool)), this, SIGNAL(resumed(bool)));
        connect(m_adaptor, SIGNAL(started(bool)), this, SIGNAL(started(bool)));

        m_adaptor->start();
    }
}

}
