/*
 * Copyright (C) 2013 Canonical Ltd
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 * Didier Roche <didier.roche@canonical.com>
 *
*/

#ifndef SYSTEMUPDATE_H
#define SYSTEMUPDATE_H

#include <QtDBus>
#include <QDBusInterface>
#include <QObject>
#include <QProcess>
#include <QUrl>
#include "update.h"

namespace UpdatePlugin {

class SystemUpdate : public QObject
{
    Q_OBJECT

public:
    explicit SystemUpdate(QObject *parent = 0);
    ~SystemUpdate();

    void downloadUpdate();
    QString applyUpdate();
    QString cancelUpdate();
    QString pauseDownload();

    void checkForUpdate();
    int downloadMode();
    void setDownloadMode(int);

public Q_SLOTS:
    void ProcessAvailableStatus(bool, bool, QString, int, QString, QString);

private Q_SLOTS:
    void ProcessSettingChanged(QString, QString);

private:
    int currentBuildNumber();

Q_SIGNALS:
    void updateAvailable(Update *update);
    void updateProgress(int percentage, double eta);
    void updatePaused(int percentage);
    void updateDownloaded();
    void updateFailed(int consecutiveFailureCount, QString lastReason);
    void infoMessageChanged();
    void downloadModeChanged();


private:
    QString m_infoMessage;
    int m_downloadMode;
    int m_currentBuildNumber;

    QDBusConnection m_systemBusConnection;
    QString m_objectPath;
    QDBusInterface m_SystemServiceIface;
};

}

#endif // SYSTEMUPDATE_H
