/*
 * Copyright 2013 Canonical Ltd.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of version 3 of the GNU Lesser General Public
 * License as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "update.h"
#include <QStringList>
#include <apt-pkg/debversion.h>
#include <QDebug>

namespace UpdatePlugin {

Update::Update(QObject *parent) :
    QObject(parent)
{
    m_systemUpdate = false;
    m_packagename = "";
    m_title = "";
    m_local_version = "";
    m_remote_version = "";
    m_dbuspath = "";
    m_update = false;
    m_update_state = false;
    m_selected = false;
    m_icon_url = "";
    m_binary_filesize = 0;
    m_click_url = "";
}

Update::~Update()
{
}

void Update::initializeApplication(QString packagename, QString title,
                                   QString version)
{
    m_packagename = packagename;
    m_title = title;
    m_local_version = version;
}

void Update::setRemoteVersion(QString& version)
{
    m_remote_version = version;

    int result = debVS.CmpVersion(m_local_version.toUtf8().data(),
                                  m_remote_version.toUtf8().data());

    m_update = result < 0;
}

void Update::setError(QString error) {
    m_error = error;
    if (!m_error.isEmpty()) {
        Q_EMIT errorChanged();
    }
}

void Update::setDescriptions(QStringList &descriptions)
{
    foreach (QString item, descriptions) {
        m_descriptions.append(QVariant::fromValue(item));
    }
}

void Update::setSystemUpdate(bool isSystem) {
    m_systemUpdate = isSystem;
    Q_EMIT systemUpdateChanged();
}

void Update::setUpdateState(bool state) {
    m_update_state = state;
    Q_EMIT updatesStateChanged();
}

void Update::setSelected(bool value) {
    m_selected = value;
    Q_EMIT selectedChanged();
}

void Update::setDbusPath(QString dbuspath) {
    m_dbuspath = dbuspath;
    Q_EMIT dbusPathChanged();
}

void Update::setBinaryFilesize(int size) {
    m_binary_filesize = size;
    Q_EMIT binaryFilesizeChanged();
}

void Update::setIconUrl(QString icon) {
    m_icon_url = icon;
    Q_EMIT iconUrlChanged();
}

void Update::setLastUpdateDate(const QString date) {
    m_lastUpdateDate = date;
    Q_EMIT lastUpdateDateChanged();
}

}
