/*
 * Copyright 2013 Canonical Ltd.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of version 3 of the GNU Lesser General Public
 * License as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef UPDATE_H
#define UPDATE_H

#include <QObject>
#include <QString>
#include <QStringList>

namespace UpdatePlugin {

class Update : public QObject
{
    Q_OBJECT
    Q_PROPERTY(bool systemUpdate READ updateState WRITE setSystemUpdate
               NOTIFY systemUpdateChanged)
    Q_PROPERTY(QString packageName READ getPackageName)
    Q_PROPERTY(QString title READ getTitle NOTIFY titleChanged)
    Q_PROPERTY(QString localVersion READ getLocalVersion
               NOTIFY localVersionChanged)
    Q_PROPERTY(QString remoteVersion READ getRemoteVersion
               NOTIFY remoteVersionChanged)
    Q_PROPERTY(QString toUpdate READ updateRequired)
    Q_PROPERTY(QString iconUrl READ iconUrl NOTIFY iconUrlChanged)
    Q_PROPERTY(int binaryFilesize READ binaryFilesize
               NOTIFY binaryFilesizeChanged)
    Q_PROPERTY(bool updateState READ updateState WRITE setUpdateState
               NOTIFY updatesStateChanged)
    Q_PROPERTY(bool selected READ selected WRITE setSelected
               NOTIFY selectedChanged)
    Q_PROPERTY(QString dbusPath READ dbusPath NOTIFY dbusPathChanged)
    Q_PROPERTY(QString error READ getError NOTIFY errorChanged)
    Q_PROPERTY(QString lastUpdateDate READ lastUpdateDate
               NOTIFY lastUpdateDateChanged)

Q_SIGNALS:
    void systemUpdateChanged();
    void titleChanged();
    void binaryFilesizeChanged();
    void iconUrlChanged();
    void localVersionChanged();
    void remoteVersionChanged();
    void updatesStateChanged();
    void selectedChanged();
    void dbusPathChanged();
    void errorChanged();
    void descriptionsChanged();
    void lastUpdateDateChanged();

public:
    explicit Update(QObject *parent = 0);
    virtual ~Update();

    bool systemUpdate() { return m_systemUpdate; }
    QString getPackageName() { return m_packagename; }
    QString getTitle() { return m_title; }
    QString getLocalVersion() { return m_local_version; }
    QString getRemoteVersion() { return m_remote_version; }
    QString dbusPath() { return m_dbuspath; }
    QString iconUrl() { return m_icon_url; }
    QString lastUpdateDate() { return m_lastUpdateDate; }
    int binaryFilesize() { return m_binary_filesize; }
    bool updateRequired() { return m_update; }
    bool updateState() { return m_update_state; }
    bool selected() { return m_selected; }
    QString getError() { return m_error; }
    QVariantList getDescriptions() { return m_descriptions; }
    const QString& getClickUrl() const { return m_click_url; }

    void setSystemUpdate(bool isSystem);
    void initializeApplication(QString packagename, QString title,
                               QString version);
    void setRemoteVersion(QString &version);
    void setUpdateState(bool state);
    void setSelected(bool value);
    void setDbusPath(QString dbuspath);
    void setBinaryFilesize(int size);
    void setIconUrl(QString icon);
    void setError(QString error);
    void setDescriptions(QStringList &descriptions);
    void setClickUrl(const QString &url) { m_click_url = url; }
    void setUpdateAvailable(bool available) { m_update = available; }
    void setLastUpdateDate(const QString date);

private:
    bool m_systemUpdate;
    QString m_packagename;
    QString m_title;
    QString m_local_version;
    QString m_remote_version;
    QString m_dbuspath;
    QString m_icon_url;
    QString m_error;
    QString m_click_url;
    QString m_lastUpdateDate;
    QVariantList m_descriptions;
    int m_binary_filesize;
    bool m_update;
    bool m_update_state;
    bool m_selected;
};

}

Q_DECLARE_TYPE(UpdatePlugin::Update)

#endif // UPDATE_H
