/*
 * Copyright 2013 Canonical Ltd.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of version 3 of the GNU Lesser General Public
 * License as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef UPDATEMANAGER_H
#define UPDATEMANAGER_H

#include <QObject>
#include <QHash>
#include <QList>
#include <QVariant>
#include <QVariantList>
#include "update.h"
#include "systemupdate.h"
#include <token.h>

#ifdef TESTS
#include "../../tests/plugins/system-update/fakeprocess.h"
#include "../../tests/plugins/system-update/fakenetwork.h"
#include "../../tests/plugins/system-update/fakedownloader.h"
#include "../../tests/plugins/system-update/fakessoservice.h"
#else
#include <ssoservice.h>
#include <QProcess>
#include "network/network.h"
#include "download/downloader.h"
#endif

using namespace UbuntuOne;

namespace UpdatePlugin {

class UpdateManager : public QObject
{
    Q_OBJECT
    Q_PROPERTY(QVariantList model READ model NOTIFY modelChanged)
    Q_PROPERTY(int downloadMode READ downloadMode WRITE setDownloadMode
               NOTIFY downloadModeChanged)

Q_SIGNALS:
    void modelChanged();
    void updatesNotFound();
    void credentialsNotFound();
    void updateAvailableFound();
    void errorFound();
    void downloadModeChanged();
    void systemUpdateDownloaded();
    
public:
    explicit UpdateManager(QObject *parent = 0);
    ~UpdateManager();

    Q_INVOKABLE void checkUpdates();
    Q_INVOKABLE void startDownload(const QString &packagename,
                                   bool systemUpdate);
    Q_INVOKABLE void applySystemUpdate() { m_systemUpdate.applyUpdate(); }

    QVariantList model() const { return m_model; }
    int downloadMode() { return m_systemUpdate.downloadMode(); }
    void setDownloadMode(int mode) { m_systemUpdate.setDownloadMode(mode); }

#ifdef TESTS
    // For testing purposes
    QHash<QString, Update*> get_apps() { return m_apps; }
    QVariantList get_model() { return m_model; }
    Token get_token() { return m_token; }
    void set_token(Token& t) { m_token = t; }
    int get_downloadMode() { return m_downloadMode; }
#endif

private Q_SLOTS:
    void processOutput();
    void processUpdates();
    void registerSystemUpdate(Update *update);
    void downloadUrlObtained(const QString &packagename, const QString &url);
    void downloadCreated(const QString &packagename, const QString &dbuspath);
    void downloadNotCreated(const QString &packagename, const QString &error);
    void handleCredentialsFound(Token token);
    void handleCredentialsNotFound();
    void clickTokenReceived(Update *app, const QString &clickToken);

private:
    QHash<QString, Update*> m_apps;
    QVariantList m_model;
    Token m_token;
    SystemUpdate m_systemUpdate;
    int m_downloadMode;

#ifdef TESTS
    FakeSsoService m_service;
    FakeNetwork m_network;
    FakeDownloader m_downloader;
    FakeProcess m_process;
#else
    SSOService m_service;
    QProcess m_process;
    Network m_network;
    Downloader m_downloader;
#endif

    void checkForUpdates();
};

}

Q_DECLARE_TYPE(UpdatePlugin::UpdateManager)

#endif // UPDATEMANAGER_H
